@@ -1,6 +1,8 @@
 package Lingua::RU::Number;
 
+use utf8;
 use strict;
+use POSIX qw/floor/;
 use vars qw($VERSION @ISA @EXPORT @EXPORT_OK);
 
 require Exporter;
@@ -11,12 +13,12 @@ require AutoLoader;
 # names by default without a very good reason. Use EXPORT_OK instead.
 # Do not simply export all your public functions/methods/constants.
 @EXPORT = qw();
-@EXPORT_OK = qw(rur_in_words);
+@EXPORT_OK = qw(rur_in_words num2words);
 
-$VERSION = '0.6';
+$VERSION = '0.61';
 
 # Preloaded methods go here.
-use vars qw(%diw %nom);
+use vars qw(%diw %nom %genders);
 
 %diw = (
     0 => {
@@ -73,6 +75,12 @@ use vars qw(%diw %nom);
     5  =>  {0 => "триллиона",1 => "триллионов",2 => "один триллион",3 => "два триллиона"}
 );
 
+%genders = (
+    0 => { 0 => "", 1 => "", 2 => "одна", 3 => "две" },
+    1 => { 0 => "", 1 => "", 2 => "один", 3 => "два" },
+    2 => { 0 => "", 1 => "", 2 => "одно", 3 => "два" },
+);
+
 my $out_rub;
 
 sub rur_in_words
@@ -143,29 +151,129 @@ sub get_string
     return $retval;
 }
 
+sub num2words {
+    my ($number, $gender) = @_;
+
+    $gender = 1 unless defined $gender; # male by default
+
+    return _get_string(0, 0, 0) unless $number; # no extra calculations for zero
+
+    my ($result, $negative);
+
+    # Negative number, just add another word
+    if ($number < 0) {
+        $number   = abs($number);
+        $negative = 1;
+    }
+
+    $result = "";
+    my $int_number = floor($number); # no doubles
+
+    for (my $i = 1; $i < 6 && $int_number >= 1; $i++) {
+        my $tmp_number = $int_number / 1000;
+        my $number_part = sprintf("%0.3f", $tmp_number - sprintf("%d", $tmp_number)) * 1000;
+
+        $int_number = floor $tmp_number; # no doubles again
+        $result = _get_string($number_part, $i, $gender) . " " . $result;
+    }
+
+    # Clean the result
+    $result =~ s/\s+/ /g;
+    $result =~ s/\s+$//;
+
+    return ($negative) ? "минус $result" : $result;
+}
+
+sub _get_string {
+    my $sum     = shift;
+    my $nominal = shift;
+    my $gender  = shift;
+    my ($result, $nom) = ('', -1);
+    
+    return unless defined $sum;
+
+    if ( ( !$nominal && $sum < 100 ) || ( $nominal > 0 && $nominal < 6 && $sum < 1000 ) ) {
+        my $s2 = sprintf( "%d", $sum / 100 );
+
+        if ( $s2 > 0 ) {    # hundreds
+            $result .= ' ' . $diw{2}{$s2}{0};
+            $nom = $diw{2}{$s2}{1};
+        }
+
+        my $sx = floor $sum - $s2 * 100;
+
+        if ( ( $sx < 20 && $sx > 0 ) || ( $sx == 0 && !$nominal ) ) {
+            $result .= " " . $diw{0}{$sx}{0};
+            $nom = $diw{0}{$sx}{1};
+        }
+        else {
+            my $s1 = floor $sx / 10;    # tens
+
+            my $s0 = sprintf( "%d", $sum - $s2 * 100 - $s1 * 10 + 0.5 );
+
+            if ( $s1 > 0 ) {
+                $result .= ' ' . $diw{1}{$s1}{0};
+                $nom = $diw{1}{$s1}{1};
+            }
+            if ( $s0 > 0 ) {
+                $result .= ' ' . $diw{0}{$s0}{0};
+                $nom = $diw{0}{$s0}{1};
+            }
+        }
+    }
+    if ( $nom >= 0 ) {
+
+        if ( $nominal == 1 ) {
+            $result .= defined $nominal ? ' ' . $genders{$gender}{$nom} : '';
+        }
+        else {
+            $result .= defined $nominal ? ' ' . $nom{$nominal}{$nom} : '';
+        }
+    }
+    $result =~ s/^\s*//g;
+    $result =~ s/\s*$//g;
+
+    return $result;
+}
+
 # Autoload methods go after =cut, and are processed by the autosplit program.
 
 1;
 __END__
 # Below is the stub of documentation for your module.
 
+=encoding utf-8
+
 =head1 NAME
 
 Lingua::RU::Number - Converts numbers to money sum in words (in Russian roubles)
+and numbers (int) to words. 
 
 =head1 SYNOPSIS
 
-  use Lingua::RU::Number qw(rur_in_words);
+  use Lingua::RU::Number qw(rur_in_words num2words);
 
-  print rur_in_words(1.01), "\n";
+  print rur_in_words(1.01), "\n"; 
+  # outputs "один рубль одна копейка"
+  
+  print num2words(32), "\n"; 
+  # outputs "тридцать два"
+  
+  print num2words(32, 1), " зуба \n"; 
+  # outputs "тридцать два зуба"
+  
+  print num2words(21, 2), " очко \n"; 
+  # outputs "двадцать одно очко"
 
 =head1 DESCRIPTION
 
-B<Lingua::RU::Number::rur_in_words()> helps you convert number to money sum in words.
+B<Lingua::RU::Number::rur_in_words()> helps you convert a number to money sum in words.
 Given a number, B<rur_in_words()> returns it as money sum in words, e.g.: 1.01 converted
-to I<odin rubl' odna kopejka>, 2.22 converted to I<dwa rublja dwadcat' dwe kopejki>.
+to I<один рубль одна копейка>, 2.22 converted to I<два рубля двадцать две копейки>.
 The target charset is B<UTF-8>.
 
+B<num2words( $number, $gender )> translates a number (integer) to text in russian, using the specified gender. B<$gender> 0|1|2 - feminine, masculine and neutral respectively. Masculine by default. Returns Unicode string.
+
 =head1 BUGS
 
 ..
@@ -174,6 +282,8 @@ The target charset is B<UTF-8>.
 
 Vladislav Safronov, E<lt>F<vlad at yandex.ru>E<gt>
 
+num2words() code borrowed from B<Lingua::RU::Num2Word> by Richard C. Jelinek E<lt>F<info@petamem.com>E<gt>, https://github.com/regru/lingua-ru-num2word/blob/master/lib/Lingua/RU/Num2Word.pm
+
 =head1 COPYRIGHT AND LICENSE
 
 Copyright (C) 2002-2015 by Vladislav Safronov.
