@@ -8,6 +8,7 @@
 
 BEGIN { $| = 1; print "1..2\n"; }
 END {print "not ok 1\n" unless $loaded; print "not ok 2\n" unless $words;}
+use utf8;
 use Lingua::RU::Number;
 $loaded = 1;
 print "ok 1\n";
@@ -28,5 +29,13 @@ $words = Lingua::RU::Number::rur_in_words(10.58);
 print "10.58 is $words\n";
 $words = Lingua::RU::Number::rur_in_words(11.11);
 print "11.11 is $words\n";
+$words = Lingua::RU::Number::num2words(11);
+print "11 бутылок пива is $words бутылок пива\n";
+$words = Lingua::RU::Number::num2words(21, 2);
+print "21 очко is $words очко\n";
+$words = Lingua::RU::Number::num2words(31, 1);
+print "31 телефон is $words телефон\n";
+$words = Lingua::RU::Number::num2words(32, 0);
+print "32 девушки is $words девушки\n";
 
 print "ok 2\n";
